@@ -142,7 +142,7 @@ let connection_string = "
     Driver={ODBC Driver 17 for SQL Server};\
     Server=localhost;\
     UID=SA;\
-    PWD=<YourStrong@Passw0rd>;\
+    PWD=My@Test@Password1;\
 ";
 
 let mut conn = env.connect_with_connection_string(connection_string)?;
@@ -168,7 +168,7 @@ use odbc_api::Environment;
 
 let env = Environment::new()?;
 
-let mut conn = env.connect("YourDatabase", "SA", "<YourStrong@Passw0rd>")?;
+let mut conn = env.connect("YourDatabase", "SA", "My@Test@Password1")?;
 # Ok::<(), odbc_api::Error>(())
 ```
 
@@ -228,7 +228,7 @@ use odbc_api::Environment;
 
 let env = Environment::new()?;
 
-let mut conn = env.connect("YourDatabase", "SA", "<YourStrong@Passw0rd>")?;
+let mut conn = env.connect("YourDatabase", "SA", "My@Test@Password1")?;
 if let Some(cursor) = conn.execute("SELECT year, name FROM Birthdays;", ())? {
     // Use cursor to process query results.
 }
@@ -386,7 +386,7 @@ let mut buffer = buffer_from_description(
     buffer_description.iter().copied()
 );
 
-let mut conn = env.connect("YourDatabase", "SA", "<YourStrong@Passw0rd>")?;
+let mut conn = env.connect("YourDatabase", "SA", "My@Test@Password1")?;
 if let Some(cursor) = conn.execute("SELECT year, name FROM Birthdays;", ())? {
     // Bind buffer to cursor. We bind the buffer as a mutable reference here, which makes it
     // easier to reuse for other queries, but we could have taken ownership.
